marxs
=====

Multi-Architecture-Raytrace-Xraymission-Simulator

.. image:: https://travis-ci.org/Chandra-MARX/marxs.svg
   :target: https://travis-ci.org/Chandra-MARX/marxs
   :alt: Continuous integration status

.. image:: https://readthedocs.org/projects/marxs/badge/?version=latest
   :target: http://marxs.readthedocs.io/en/latest/
   :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/Chandra-MARX/marxs/badge.svg?branch=master 
   :target: https://coveralls.io/github/Chandra-MARX/marxs?branch=master
   :alt: Fraction of code covered by tests

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
   :target: http://www.astropy.org/
   :alt: Powered by astropy
   
.. image:: https://zenodo.org/badge/34215358.svg
   :target: https://zenodo.org/badge/latestdoi/34215358
   :alt: Link to last release with DOI
